var group__PkgClassificationConcepts =
[
    [ "CGAL::Classification::Classifier", "classCGAL_1_1Classification_1_1Classifier.html", [
      [ "operator()", "classCGAL_1_1Classification_1_1Classifier.html#a274bcaf30e8696f6b3e5e8afb4f29ab8", null ]
    ] ],
    [ "CGAL::Classification::NeighborQuery", "classCGAL_1_1Classification_1_1NeighborQuery.html", [
      [ "value_type", "classCGAL_1_1Classification_1_1NeighborQuery.html#a610b61b585f5dd6f86f38ef8a6d0e603", null ],
      [ "operator()", "classCGAL_1_1Classification_1_1NeighborQuery.html#a3c8137c09f5ce328baddb4ee2cda474c", null ]
    ] ]
];